@@ -95,7 +95,7 @@ def minkowski_deviation(x: np.ndarray, order=2) -> np.float64:
 
     See Also
     --------
-    np.std : Standard deviation.
+    numpy.std : Standard deviation.
 
     References
     ----------
@@ -375,7 +375,8 @@ def correlation_ratio(X: np.ndarray, y: np.ndarray) -> np.float64:
 
 def misiak_correlation(x: np.ndarray, y: np.ndarray, X: np.ndarray) -> np.float64:
     '''
-    Misiak's n-inner correlation coefficient.
+    Misiak's n-inner correlation coefficient based on the n-inner product space
+    presented in Misiak and Ryz 2000.
 
     Parameters
     ----------
@@ -391,6 +392,10 @@ def misiak_correlation(x: np.ndarray, y: np.ndarray, X: np.ndarray) -> np.float6
         : np.float64
             Misiak correlation score.
 
+    References
+    ----------
+    .. [1] Misiak, Aleksander. Ryz, Alicja. 2000. "n-Inner Product Spaces and Projections.", https://www.emis.de/journals/MB/125.1/mb125_1_5.pdf
+
     Examples
     --------
     >>> import numpy as np
@@ -458,6 +463,11 @@ def signum_correlation(X: np.ndarray) -> np.float64:
     '''
     Signum correlation coefficient.
 
+    This function estimates
+
+    .. math::
+        R_c \\left[ X_1, \\cdots, X_n \\right] = \\frac{\\mathbb{E} \\left[ \\prod_{j=1}^{n} \\text{sign} \\left( X_j - \\mathbb{E}[X_j] \\right) \\right]}{\\prod_{j=1}^{n} \\sqrt[n]{\\mathbb{E}\\left[ |\\text{sign} \\left( X_j - \\mathbb{E}[X_j] \\right)|^n \\right]}}
+
     Parameters
     ----------
         X: array-like
@@ -467,6 +477,14 @@ def signum_correlation(X: np.ndarray) -> np.float64:
     ----------
         : float
             Signum correlation score.
+
+    See Also
+    --------
+    scipy.stats.kendalltau : Kendall's :math:`\\tau`
+
+    Notes
+    -----
+    On the face of it this coefficient seems the same as Kendall's :math:`\\tau` due to taking products of signs, however they are distinct. Kendall's :math:`\\tau` computes an average of the discordant pairs subtracted from the concordant pairs of points.
     '''
     transform = X - np.mean(X, axis=0)
     transform = np.sign(transform)
@@ -558,13 +576,13 @@ def wang_zheng_correlation(X: np.ndarray) -> np.float64:
     result : np.float64
             Unsigned correlation coefficient.
 
-    References
-    ----------
-    .. [1] Wang, Jianji. Zheng, Nanning. 2014. "Measures of Correlation for Multiple Variables", https://arxiv.org/abs/1401.4827
-
     Notes
     -----
     The complement of this statistic is the unsigned incorrelation coefficient.
+
+    References
+    ----------
+    .. [1] Wang, Jianji. Zheng, Nanning. 2014. "Measures of Correlation for Multiple Variables", https://arxiv.org/abs/1401.4827
     '''
     result = X.T
     result = np.corrcoef(result)
